SmartTextStyle class

Constructors

SmartTextStyle({String? symbol, required TextStyle style})
A wrapper for a TextStyle that can optionally be associated with a symbol identifier.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle
final
symbol String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited