TextInfo class

Constructors

TextInfo({required int start, required int end, required String text})
Describes an immutable span of text with start and end offsets and the associated substring.
const

Properties

end int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final
text String
final

Methods

contains(int offset) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited