paint method
Draws the rendered text to the canvas at the specified offset.
Implementation
@override
void paint(PaintingContext context, Offset offset) {
_textPainter.paint(context.canvas, offset);
}
Draws the rendered text to the canvas at the specified offset.
@override
void paint(PaintingContext context, Offset offset) {
_textPainter.paint(context.canvas, offset);
}