maxLines property
int?
get
maxLines
The maximum number of lines to display, or null for unlimited lines.
Setting this property updates the text painter and triggers a layout recalculation.
Implementation
int? get maxLines => _maxLines;
set
maxLines
(int? value)
Implementation
set maxLines(int? value) {
if (_maxLines == value) return;
_maxLines = value;
_textPainter.maxLines = value;
markNeedsLayout();
}