textAlign property
TextAlign
get
textAlign
How the text should be aligned within its bounds.
Setting this property updates the text painter and triggers a layout recalculation.
Implementation
TextAlign get textAlign => _textAlign;
set
textAlign
(TextAlign value)
Implementation
set textAlign(TextAlign value) {
if (_textAlign == value) return;
_textAlign = value;
_textPainter.textAlign = value;
markNeedsLayout();
}